#
# spec file for package partclone
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Mariusz Fik <fisiu@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           partclone
Version:        0.3.32
Release:        1.5
Summary:        File System Clone Utilities
License:        GPL-2.0-or-later
URL:            https://partclone.org/
Source:         https://github.com/Thomas-Tsai/partclone/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  fdupes
BuildRequires:  nilfs-utils-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libntfs-3g)
BuildRequires:  pkgconfig(mount)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(uuid)

%description
A set of file system clone utilities, including
ext2/3, reiserfs, reiser4, xfs, hfs+ file systems

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -fcommon"
autoreconf -fiv
%configure \
  --enable-ncursesw \
  --enable-fuse \
  --enable-fs-test \
  --enable-btrfs \
  --enable-extfs \
  --enable-fat \
  --enable-hfsp \
  --enable-apfs \
  --enable-ntfs \
  --enable-xfs \
  --enable-f2fs \
  --enable-nilfs2 \
  --enable-minix \
  --enable-exfat
# During build following occurs, but it seems harmless
# files fail-mbr.bin and fail-mbr.bin.orig differ significantly:
%make_build LIBS="-lncursesw -lpthread -lfuse" ||:

%install
%make_install INSTLIBDIR=%{buildroot}%{_datadir}/%{name}
%fdupes -s %{buildroot}%{_datadir}
#mv %{buildroot}%{_sysconfdir}/bash_completion.d/partclone-prompt \
#  %{buildroot}%{_datadir}/bash-completion/completions/
%find_lang %{name}

%files
%license COPYING
%doc ChangeLog README.md
%{_datadir}/bash-completion/completions/partclone-prompt
%{_sbindir}/partclone.apfs
%{_sbindir}/partclone.btrfs
%{_sbindir}/partclone.chkimg
%{_sbindir}/partclone.dd
%{_sbindir}/partclone.ext2
%{_sbindir}/partclone.ext3
%{_sbindir}/partclone.ext4
%{_sbindir}/partclone.ext4dev
%{_sbindir}/partclone.extfs
%{_sbindir}/partclone.exfat
%{_sbindir}/partclone.f2fs
%{_sbindir}/partclone.fat
%{_sbindir}/partclone.fat12
%{_sbindir}/partclone.fat16
%{_sbindir}/partclone.fat32
%{_sbindir}/partclone.imgfuse
%{_sbindir}/partclone.hfs+
%{_sbindir}/partclone.hfsp
%{_sbindir}/partclone.hfsplus
%{_sbindir}/partclone.imager
%{_sbindir}/partclone.info
%{_sbindir}/partclone.minix
%{_sbindir}/partclone.nilfs2
%{_sbindir}/partclone.ntfs
%{_sbindir}/partclone.ntfsfixboot
%{_sbindir}/partclone.ntfsreloc
%{_sbindir}/partclone.restore
%{_sbindir}/partclone.vfat
%{_sbindir}/partclone.xfs
%{_mandir}/man8/partclone.8%{?ext_man}
%{_mandir}/man8/partclone.btrfs.8%{?ext_man}
%{_mandir}/man8/partclone.chkimg.8%{?ext_man}
%{_mandir}/man8/partclone.dd.8%{?ext_man}
%{_mandir}/man8/partclone.ext2.8%{?ext_man}
%{_mandir}/man8/partclone.ext3.8%{?ext_man}
%{_mandir}/man8/partclone.ext4.8%{?ext_man}
%{_mandir}/man8/partclone.ext4dev.8%{?ext_man}
%{_mandir}/man8/partclone.extfs.8%{?ext_man}
%{_mandir}/man8/partclone.exfat.8%{?ext_man}
%{_mandir}/man8/partclone.f2fs.8%{?ext_man}
%{_mandir}/man8/partclone.fat.8%{?ext_man}
%{_mandir}/man8/partclone.fat12.8%{?ext_man}
%{_mandir}/man8/partclone.fat16.8%{?ext_man}
%{_mandir}/man8/partclone.fat32.8%{?ext_man}
%{_mandir}/man8/partclone.hfs+.8%{?ext_man}
%{_mandir}/man8/partclone.hfsp.8%{?ext_man}
%{_mandir}/man8/partclone.hfsplus.8%{?ext_man}
%{_mandir}/man8/partclone.imager.8%{?ext_man}
%{_mandir}/man8/partclone.info.8%{?ext_man}
%{_mandir}/man8/partclone.minix.8%{?ext_man}
%{_mandir}/man8/partclone.nilfs2.8%{?ext_man}
%{_mandir}/man8/partclone.ntfs.8%{?ext_man}
%{_mandir}/man8/partclone.ntfsfixboot.8%{?ext_man}
%{_mandir}/man8/partclone.ntfsreloc.8%{?ext_man}
%{_mandir}/man8/partclone.restore.8%{?ext_man}
%{_mandir}/man8/partclone.vfat.8%{?ext_man}
%{_mandir}/man8/partclone.xfs.8%{?ext_man}
%{_datadir}/partclone

%files lang -f %{name}.lang

%changelog
* Thu Aug  1 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.32:
  * update hfsplus log
  * fix ntfs error for ' read error: Success'
  * add option prog_second to display in seconds
  * Fix tiny resource leak. by @TMR5454 in #248
  * Add missing return in libvmfs_version(). by @TMR5454 in #249
  * Fix get_exec_name(): when partclone in installed, there is no '/' in argv0 by @pfrouleau in #55
  * Include the NTFS Boot Record backup in the cloned image by @pfrouleau in #54
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.27:
  * add read-direct-io and write-direct-io options for O_DIRECT
    flag
  * add date time to log file
* Fri Sep 29 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 0.3.26:
  * add the direct-io option for writing data to a TARGET device or file.
  * correction for item at offset 76
  * report used blocks and free space based on bitmap
- force higher gcc version on Leap
* Mon Sep  4 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.25:
  * update btrfs library to 6.3.3
  * Full Changelog:
    https://github.com/Thomas-Tsai/partclone/compare/0.3.24...0.3.25
- update to 0.3.24:
  * IO stream support for torrent info file.
  * split jobs in github action
  * add dockerfile and test on tag creating
  * Handle absence of mtrace.h (e.g. uClibc) gracefully
  * Link with -lm for isnormal()/__fpclassifyf() as needed
  * Add Russian language file.
  * Update partclone.c
  * Add missing space before opening parenthesis
  * Add german language
  * Update language files
  * Add localization
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.23:
  * update btrfs clone to 6.0.1
  * create github actions for build test
  * Support parallel unit-testing
  * Reflect partclone 0.3.22 release in configure.ac
  * Don't target Btrfs and exFAT tests twice
  * Create manual-on-host.yml
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.3.22:
  * fix log message to add new line after "Open devicefile successfully"
  * Add missing space before opening parenthesis
  * Skip FAT tests on big-endian architectures
  * Skip F2FS tests on big-endian architectures
  * Increase F2FS default test size to 100+ MB
  * Increase XFS default test image size to 300+ MB
  * fail-mbr: Remove binutils section .note.gnu.build-id using objcopy
  * Change C99 for loop init to C89 for compatibility
  * update autotools build files
  * Avoid redefining _GNU_SOURCE, _LARGEFILE64_SOURCE
  * Support FUSE 2.x API
  * Check argument count in partclone.imgfuse
  * Support out-of-tree builds for BTRFS and XFS
  * Avoid uninitialized variables to prevent compiler warnings
  * Check for EVP_MD_CTX_reset
  * Remove unused variables to silence compiler warnings
  * Detect FUSE version and explicitly print “yes” or “no” regarding
    filesystem support
  * Fix MBR builds for x86, non-x86 and out-of-tree
  * Support unit-testing in out-of-tree builds
  * Fix typos
* Tue May  3 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.3.20:
  * Fix apfs support
  * Add stdout support
* Mon Mar 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.19:
  * Ignore free space check if compression is enabled. by @zboszor in #147
  * fix: crash when backing up swap partition by @justforlxz in #148
  * Update to btrfs-progs 5.4.1 by @boretom in #151
  * Change C99 for loop init to C89 for compatibility by @robert-scheck in #152
  * doc: document the image formats by @pfrouleau in #157
  * doc: fix typo for logfile argument by @mjoerg in #162
  * WIP: Add block_size and blocks_total in torrent.info to provide partition info by @tjjh89017 in #164
  * Use EVP OpenSSL API by @zboszor in #165
  * Fix using EVP OpenSSL API by @zboszor in #166
  * Fix typo by @jwilk in #169
  * Support HFS+ wrapper volumes by @vasi in #172
  * Domain file doc by @jowagner in #175
  * Docs typo "normanly" by @jowagner in #178
  * How to contribute docs: readme by @jowagner in #179
* Wed Sep 29 2021 Paolo Stivanin <info@paolostivanin.com>
- update to 0.3.18:
  * Add block_size and blocks_total in torrent.info to provide
    partition info
  * change C99 for loop init to C89 for compatibility
  * try to fix ignore_crc not working properly
* Mon Mar 22 2021 Martin Pluskal <mpluskal@suse.com>
- Drop dependency on libreiserfs
* Wed Mar 10 2021 Martin Pluskal <mpluskal@suse.com>
- Resolve build failure on Tumleweed
* Tue Dec 29 2020 Dirk Müller <dmueller@suse.com>
- update to 0.3.17:
  * fix progress
  * update btrfs to 5.4.1
  * fix crash when backing up swap partition
  * Ignore free space check if compression is enabled
* Mon Jul 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 0.3.15
  * XFS fixes
* Thu Jun 11 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Thu Sep 26 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.13"
  * Add support for apfs
- Update download url
* Fri Dec 14 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.3.12:
  * Support compressed cloned images
- Enable exfat support
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 0.3.11 (boo#1130986):
  * update xfs
* Tue Feb 21 2017 mpluskal@suse.com
- Update to version 0.3.5a:
  * Support for fuse
  * Several bugfixes and internal changes
  * Resolves boo#1028904 CVE-2017-6596
* Sun Jul  3 2016 mpluskal@suse.com
- Update to version 0.2.89:
  * small bugfixes
* Sun Mar 20 2016 mpluskal@suse.com
- Switch to 0.2.88 (as 0.3 branch seems to be currently abandoned)
- Enable more filesystems
- Remove ppc excludes as build now succeeds
- Cleanup spec file
- Drop upstreamed partclone-missing-includes.patch
* Thu Aug 13 2015 normand@linux.vnet.ibm.com
- ExcludeArch:    ppc ppc64 ppc64le
  PowerPC do not support the fail-mbr/fail-mbr.S
* Wed Jun 24 2015 dimstar@opensuse.org
- Add partclone-missing-includes.patch: Fix build with GCC5 by
  correctly including the needed headers.
* Sat Mar 21 2015 mpluskal@suse.com
- Remove conditions that applied to old releases
* Wed Mar 18 2015 mpluskal@suse.com
- Update to 0.3.0~gitbcaa
  * for a full list of changes see attached Changelog
* Thu Oct  3 2013 fisiu@opensuse.org
- Update to 0.2.58:
  * ship failmbr
  * fixed jfs issues
  * fixed ncurses interface
  * updated doc and man pages
* Wed Nov  7 2012 fisiu@opensuse.org
- Update to 0.2.48:
  * fixed VMFS-5 and NTFS cloning
  * updated the ntfsfixboot version
  * memory usage optimized
  * updated man pages
- Build with support for btrfs, extfs, fat, hfsp, ntfs, reiserfs.
* Thu Apr 19 2012 highwaystar.ru@gmail.com
- update to 0.2.38
* Sun Sep 19 2010 highwaystar.ru@gmail.com
- built with ntfs support
- built with jfs support
* Fri Sep 17 2010 highwaystar.ru@gmail.com
- initial build for openSUSE
- not all filesystems supported yet
